@@ -55,55 +55,55 @@ RadioConfiguration::RadioConfiguration (TQWidget *parent, const IErrorLogClient
       m_logger(logger),
       m_dirty(true)
 {
-    TQObject::connect(listStations, TQT_SIGNAL(sigCurrentStationChanged(int)),
-                     this, TQT_SLOT(slotStationSelectionChanged(int)));
-    TQObject::connect(buttonSelectPixmapFile, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(slotSelectPixmap()));
-    TQObject::connect(buttonNewStation, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(slotNewStation()));
-    TQObject::connect(buttonDeleteStation, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(slotDeleteStation()));
-    TQObject::connect(editPixmapFile, TQT_SIGNAL(textChanged(const TQString &)),
-                     this, TQT_SLOT(slotPixmapChanged(const TQString &)));
-    TQObject::connect(editStationName, TQT_SIGNAL(textChanged(const TQString &)),
-                     this, TQT_SLOT(slotStationNameChanged(const TQString &)));
-    TQObject::connect(editStationShortName, TQT_SIGNAL(textChanged(const TQString &)),
-                     this, TQT_SLOT(slotStationShortNameChanged(const TQString &)));
-    TQObject::connect(editVolumePreset, TQT_SIGNAL(valueChanged(int)),
-                     this, TQT_SLOT(slotVolumePresetChanged(int)));
-    TQObject::connect(buttonStationUp, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(slotStationUp()));
-    TQObject::connect(buttonStationDown, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(slotStationDown()));
-    TQObject::connect(listStations, TQT_SIGNAL(sigStationActivated(int)),
-                     this, TQT_SLOT(slotActivateStation( int )));
-    TQObject::connect(buttonLoadPresets, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(slotLoadPresets()));
-    TQObject::connect(buttonStorePresets, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(slotStorePresets()));
-    TQObject::connect(buttonLastChangeNow, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(slotLastChangeNow()));
+    TQObject::connect(listStations, TQ_SIGNAL(sigCurrentStationChanged(int)),
+                     this, TQ_SLOT(slotStationSelectionChanged(int)));
+    TQObject::connect(buttonSelectPixmapFile, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(slotSelectPixmap()));
+    TQObject::connect(buttonNewStation, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(slotNewStation()));
+    TQObject::connect(buttonDeleteStation, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(slotDeleteStation()));
+    TQObject::connect(editPixmapFile, TQ_SIGNAL(textChanged(const TQString &)),
+                     this, TQ_SLOT(slotPixmapChanged(const TQString &)));
+    TQObject::connect(editStationName, TQ_SIGNAL(textChanged(const TQString &)),
+                     this, TQ_SLOT(slotStationNameChanged(const TQString &)));
+    TQObject::connect(editStationShortName, TQ_SIGNAL(textChanged(const TQString &)),
+                     this, TQ_SLOT(slotStationShortNameChanged(const TQString &)));
+    TQObject::connect(editVolumePreset, TQ_SIGNAL(valueChanged(int)),
+                     this, TQ_SLOT(slotVolumePresetChanged(int)));
+    TQObject::connect(buttonStationUp, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(slotStationUp()));
+    TQObject::connect(buttonStationDown, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(slotStationDown()));
+    TQObject::connect(listStations, TQ_SIGNAL(sigStationActivated(int)),
+                     this, TQ_SLOT(slotActivateStation( int )));
+    TQObject::connect(buttonLoadPresets, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(slotLoadPresets()));
+    TQObject::connect(buttonStorePresets, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(slotStorePresets()));
+    TQObject::connect(buttonLastChangeNow, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(slotLastChangeNow()));
 
-    connect(editMaintainer, TQT_SIGNAL(textChanged(const TQString &)),    TQT_SLOT(slotSetDirty()));
-    connect(editLastChange, TQT_SIGNAL(valueChanged(const TQDateTime &)), TQT_SLOT(slotSetDirty()));
-    connect(editCountry,    TQT_SIGNAL(textChanged(const TQString &)),    TQT_SLOT(slotSetDirty()));
-    connect(editCity,       TQT_SIGNAL(textChanged(const TQString &)),    TQT_SLOT(slotSetDirty()));
-    connect(editMedia,      TQT_SIGNAL(textChanged(const TQString &)),    TQT_SLOT(slotSetDirty()));
-    connect(editComment,    TQT_SIGNAL(textChanged(const TQString &)),    TQT_SLOT(slotSetDirty()));
-    connect(editPresetFile, TQT_SIGNAL(textChanged(const TQString &)),    TQT_SLOT(slotSetDirty()));
+    connect(editMaintainer, TQ_SIGNAL(textChanged(const TQString &)),    TQ_SLOT(slotSetDirty()));
+    connect(editLastChange, TQ_SIGNAL(valueChanged(const TQDateTime &)), TQ_SLOT(slotSetDirty()));
+    connect(editCountry,    TQ_SIGNAL(textChanged(const TQString &)),    TQ_SLOT(slotSetDirty()));
+    connect(editCity,       TQ_SIGNAL(textChanged(const TQString &)),    TQ_SLOT(slotSetDirty()));
+    connect(editMedia,      TQ_SIGNAL(textChanged(const TQString &)),    TQ_SLOT(slotSetDirty()));
+    connect(editComment,    TQ_SIGNAL(textChanged(const TQString &)),    TQ_SLOT(slotSetDirty()));
+    connect(editPresetFile, TQ_SIGNAL(textChanged(const TQString &)),    TQ_SLOT(slotSetDirty()));
 
     mailLabel->setText("mailto:witte-presets@kawo1.rwth-aachen.de");
     mailLabel->setURL ("mailto:witte-presets@kawo1.rwth-aachen.de");
-    TQObject::connect(mailLabel, TQT_SIGNAL(leftClickedURL(const TQString &)),
-                     this, TQT_SLOT(slotSendPresetsByMail(const TQString &)));
+    TQObject::connect(mailLabel, TQ_SIGNAL(leftClickedURL(const TQString &)),
+                     this, TQ_SLOT(slotSendPresetsByMail(const TQString &)));
 
-    TQObject::connect(buttonSearchStations, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(slotSearchStations0()));
+    TQObject::connect(buttonSearchStations, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(slotSearchStations0()));
 
     devicePopup = new TQPopupMenu(buttonSearchStations);
     buttonSearchStations->setPopup(devicePopup);
-    TQObject::connect(devicePopup, TQT_SIGNAL(activated(int)),
-                     this, TQT_SLOT(slotSearchStations(int)));
+    TQObject::connect(devicePopup, TQ_SIGNAL(activated(int)),
+                     this, TQ_SLOT(slotSearchStations(int)));
 }
 
 
@@ -235,8 +235,8 @@ void RadioConfiguration::slotStationSelectionChanged(int idx)
             c = s->createEditor();
             if (c) {
                 c->reparent(this, TQPoint(0,0), true);
-                TQObject::connect(c, TQT_SIGNAL(changed(RadioStationConfig*)),
-                                 this, TQT_SLOT(slotStationEditorChanged(RadioStationConfig*)));
+                TQObject::connect(c, TQ_SIGNAL(changed(RadioStationConfig*)),
+                                 this, TQ_SLOT(slotStationEditorChanged(RadioStationConfig*)));
                 stationEditors.insert(s->getClassName(), c);
                 stackStationEdit->addWidget(c);
             }
