@@ -23,11 +23,11 @@
 #endif
 
 #include <tqwidget.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 class RadioStation;
 
-class KDE_EXPORT RadioStationConfig : public TQWidget
+class TDE_EXPORT RadioStationConfig : public TQWidget
 {
 TQ_OBJECT
 
@@ -43,7 +43,7 @@ signals:
 };
 
 
-class KDE_EXPORT UndefinedRadioStationConfig : public RadioStationConfig
+class TDE_EXPORT UndefinedRadioStationConfig : public RadioStationConfig
 {
 TQ_OBJECT
 
@@ -59,7 +59,7 @@ public:
 
 class TQSpinBox;
 
-class KDE_EXPORT FrequencyRadioStationConfig : public RadioStationConfig
+class TDE_EXPORT FrequencyRadioStationConfig : public RadioStationConfig
 {
 TQ_OBJECT
 
